@@ -2,6 +2,7 @@ from pathlib import Path
 from typing import Optional
 
 from poetry.core.masonry.builders.builder import BuildIncludeFile
+from poetry_multiproject_plugin.workspace import namespacing
 
 
 def relative_to_workspace(target) -> Path:
@@ -20,7 +21,7 @@ def relative_to_project_root(self) -> Path:
 
 def relative_to_source_root(self) -> Path:
     if self.workspace:
-        return relative_to_workspace(self)
+        return namespacing.create_namespaced_path(self.path, self.workspace)
 
     if self.source_root is not None:
         return self.path.relative_to(self.source_root)
